@@ -41,18 +41,18 @@ class EnvDBResource(object):
             start_time = None
             work_time_list = list()
             for item in value:
-                if item[1] == b"running":
+                if item[1] == "running":
                     if start_time is None:
                         start_time = item[2]
                     else:
                         temp_work_time = item[2] - start_time
                         work_time_list.append(temp_work_time.total_seconds())
                         start_time = item[2]
-                elif item[1] == b"idle" and start_time is not None:
+                elif item[1] == "idle" and start_time is not None:
                     temp_work_time = item[2] - start_time
                     work_time_list.append(temp_work_time.total_seconds())
                     start_time = None
-                elif item[1] == b"online":
+                elif item[1] == "online":
                     start_time = None
             result = {
                 "date": key,
